@@ -9,6 +9,8 @@ pub mod integer;
 pub mod boolean;
 pub mod function;
 pub mod userdata;
+pub mod ltuserdata;
+pub mod thread;
 
 pub use self::number::LuaNumber;
 pub use self::string::LuaString;
@@ -19,6 +21,8 @@ pub use self::integer::LuaInteger;
 pub use self::boolean::LuaBool;
 pub use self::function::LuaFunction;
 pub use self::userdata::LuaUserdata;
+pub use self::ltuserdata::LuaLightUserdata;
+pub use self::thread::LuaThread;
 
 /// Any value that can represent an Index on a Lua Stack
 pub trait LuaStackable {
